==> nmail-php-patch-2.3.1-to-2.4.0.tgz: nmail/mail_attach_down.php <==
<?
require_once('include/global.php');
require_once('include/mail_lib.php');
require_once('include/file.php');
require_once('conf.inc.php');


// check
	if (!$_GET['mb_id'] || !$_GET['mf_no'] || !$_GET['mf_an_struct'])
		msg('ùٸ URL Ͽ ֽʽÿ');


	// [2008-04-03]  ٿε ð 
		if (isset($G_SYS['DOWNLOAD_TIME_LIMIT']))
			set_time_limit($G_SYS['DOWNLOAD_TIME_LIMIT']);


// data
	$DEBUG['db_select']['start'] = getmicrotime();

	// set data
		$mail_file_table = $AUTH[auth_m_mf_table];

	// db - select
		$sql = "
			SELECT
				mf_filename, mf_attach_names
			FROM
				$mail_file_table
			WHERE
				mf_no='" . $_GET['mf_no'] . "'
				AND m_no='" . $AUTH['auth_m_no'] . "'
				AND mb_id='". $_GET['mb_id']. "'
			";
		$row = db_get_row($sql);

	// db disconnect
		unset_db();

	$DEBUG['db_select']['exec'] += getmicrotime() - $DEBUG['db_select']['start'];


// download
	$DEBUG['attach_save']['start'] = getmicrotime();

	$mail_file = get_mail_dir().'/'.get_mb_dir($_GET['mb_id']).'/'.$row['mf_filename'];
	if (!file_exists($mail_file) || !is_readable($mail_file))
	{
		error("   ʰų ۹̼ ߸Ǿϴ.\n=> ". $mail_file, 'FILE');
	}	// if()

	// [2008-02-26] ϸ  ٿε尡  ʴ  . (ϸ ޹ ʰ 񿡼 ٷ )
	$an = attach_names_toarray($row['mf_attach_names']);
	$as = array_search($_GET['mf_an_struct'], $an['struct']);
	if ($as === false)
		error(" Ͽ ÷(".$_GET['mf_an_struct'].")   ϴ.\n=> ". $mail_file, 'FILE');

	$contents = get_mailparse_attachment($mail_file, $_GET['mf_an_struct']);
	file_down_headeronly($contents, $an['name'][$as]);

	$DEBUG['attach_save']['exec'] += getmicrotime() - $DEBUG['attach_save']['start'];		


// ٿε带   .
#require_once('include/global_end.php');
?>

==> nmail-php-patch-2.5.2-to-2.6.1.tgz: nmail/mail_attach_down.php <==
<?
require_once('include/global.php');
require_once('include/mail_lib.php');
require_once('include/file.php');
require_once('conf.inc.php');


// check
	if (!$_GET['mb_id'] || !$_GET['mf_no'] || !$_GET['mf_an_struct'])
		msg('ùٸ URL Ͽ ֽʽÿ');


	// [2008-04-03]  ٿε ð 
		if (isset($G_SYS['DOWNLOAD_TIME_LIMIT']))
			set_time_limit($G_SYS['DOWNLOAD_TIME_LIMIT']);


// data
	$DEBUG['db_select']['start'] = getmicrotime();

	// set data
		$mail_file_table = $AUTH[auth_m_mf_table];

	// db - select
		$sql = "
			SELECT
				mf_filename, mf_attach_names
			FROM
				$mail_file_table
			WHERE
				mf_no='" . $_GET['mf_no'] . "'
				AND m_no='" . $AUTH['auth_m_no'] . "'
				AND mb_id='". $_GET['mb_id']. "'
			";
		$row = db_get_row($sql);

		// [2009-07-01]
		if (!$row)
			msg(" ʴ Դϴ.\\n\\n̹ Ǿų ٸ  Ű  ֽϴ.");

	$DEBUG['db_select']['exec'] += getmicrotime() - $DEBUG['db_select']['start'];


// download
	$DEBUG['attach_save']['start'] = getmicrotime();

	$mail_file = get_mail_dir().'/'.get_mb_dir($_GET['mb_id']).'/'.$row['mf_filename'];
	// [2013-04-30] POP3     ,  Ȯϰ .
	//if (!file_exists($mail_file) || !is_readable($mail_file))
	if (!file_exists($mail_file))
	{
		$sql = "
			DELETE
			FROM
				".$AUTH[auth_m_mf_table]."
			WHERE
				mf_no='" . $_GET['mf_no'] . "'
				AND m_no='" . $AUTH['auth_m_no'] . "'
				AND mb_id='". $_GET['mb_id']. "'
			";
		db_query($sql);
		msg(" ʴ Դϴ.\\n\\nƿ Ŭ̾Ʈ POP3 񽺸   \\n\\n[ ޽ 纻 ]ɼ üũ ʾ Ǿ ɼ ϴ.");
	}	// if()

	// db disconnect
		unset_db();

	if (!is_readable($mail_file))
		error("   ʰų ۹̼ ߸Ǿϴ.\n=> ". $mail_file, 'FILE');

	// [2008-02-26] ϸ  ٿε尡  ʴ  . (ϸ ޹ ʰ 񿡼 ٷ )
	$an = attach_names_toarray($row['mf_attach_names']);
	$as = array_search($_GET['mf_an_struct'], $an['struct']);
	if ($as === false)
		error(" Ͽ ÷(".$_GET['mf_an_struct'].")   ϴ.\n=> ". $mail_file, 'FILE');

	$contents = get_mailparse_attachment($mail_file, $_GET['mf_an_struct']);
	file_down_headeronly($contents, $an['name'][$as]);

	$DEBUG['attach_save']['exec'] += getmicrotime() - $DEBUG['attach_save']['start'];		


// ٿε带   .
#require_once('include/global_end.php');
?>
